import pytest
from quixote import cleanup

from wcs.qommon.http_request import HTTPRequest
from wcs.workflows import Workflow

from ..utilities import clean_temporary_pub, create_temporary_pub


def setup_module(module):
    cleanup()


def teardown_module(module):
    clean_temporary_pub()


@pytest.fixture
def pub():
    pub = create_temporary_pub()
    pub.cfg['language'] = {'language': 'en'}
    pub.cfg['identification'] = {'methods': ['password']}
    pub.write_cfg()
    req = HTTPRequest(None, {'SERVER_NAME': 'example.net', 'SCRIPT_NAME': ''})
    req.response.filter = {}
    req._user = None
    pub._set_request(req)
    pub.set_config(req)
    return pub


def test_migrate_hide_submit_button(pub):
    Workflow.wipe()

    wf = Workflow(name='xxx')
    st1 = wf.add_status('Status1')
    st1.add_action('form')
    wf.store()

    # new value is to hide
    assert wf.possible_status[0].items[0].hide_submit_button is True

    # new value is kept on reload
    wf = Workflow.get(wf.id)
    assert wf.possible_status[0].items[0].hide_submit_button is True

    # simulate older action, without a value set
    del wf.possible_status[0].items[0].__dict__['hide_submit_button']
    wf.store()

    wf = Workflow.get(wf.id)
    assert wf.possible_status[0].items[0].hide_submit_button is False

    # simulate older action, with a value set (no change)
    wf.possible_status[0].items[0].hide_submit_button = True
    wf.store()

    wf = Workflow.get(wf.id)
    assert wf.possible_status[0].items[0].hide_submit_button is True
