import pytest
import responses
from quixote import cleanup

from wcs.formdef import FormDef
from wcs.qommon.http_request import HTTPRequest
from wcs.wf.wscall import WebserviceCallStatusItem

from ..utilities import clean_temporary_pub, create_temporary_pub


def setup_module(module):
    cleanup()


def teardown_module(module):
    clean_temporary_pub()


@pytest.fixture
def pub(request):
    pub = create_temporary_pub()
    pub.cfg['language'] = {'language': 'en'}
    pub.write_cfg()
    req = HTTPRequest(None, {'SERVER_NAME': 'example.net', 'SCRIPT_NAME': ''})
    req.response.filter = {}
    req._user = None
    pub._set_request(req)
    pub.set_config(req)
    return pub


def test_wscall_record_errors(pub):
    pub.user_class.wipe()
    FormDef.wipe()

    formdef = FormDef()
    formdef.name = 'test'
    formdef.fields = []
    formdef.store()
    formdef.data_class().wipe()

    formdata = formdef.data_class()()
    formdata.just_created()
    formdata.store()

    wscall = WebserviceCallStatusItem()
    wscall.url = 'http://test/'
    wscall.varname = 'varname'
    wscall.action_on_4xx = ':pass'
    wscall.record_errors = True

    # error with json data (stored as a string)
    with responses.RequestsMock() as rsps:
        rsps.get('http://test', status=404, json={'err': 1})
        wscall.perform(formdata)
        assert formdata.evolution[-1].parts[-1].get_json_export_dict() == {
            'type': 'wscall-error',
            'summary': '404 Not Found',
            'label': None,
            'data': '{"err": 1}',
        }

    # error with bytes that can be stored as string
    with responses.RequestsMock() as rsps:
        rsps.get('http://test', status=404, body=b"test bytes")
        wscall.perform(formdata)
        assert formdata.evolution[-1].parts[-1].get_json_export_dict() == {
            'type': 'wscall-error',
            'summary': '404 Not Found',
            'label': None,
            'data': 'test bytes',
        }

    # error with bytes that cannotbe stored as string
    with responses.RequestsMock() as rsps:
        rsps.get('http://test', status=404, body=b'\xf1')
        wscall.perform(formdata)
        assert formdata.evolution[-1].parts[-1].get_json_export_dict() == {
            'type': 'wscall-error',
            'summary': '404 Not Found',
            'label': None,
            'data_b64': '8Q==\n',
        }
